import vizontele
from .diziay import DiziayCrawler
from .dizibox import DiziboxCrawler
from .dizilab import DizilabCrawler
from .dizimag import DizimagCrawler
from .dizimek import DizimekCrawler
from .dizipub import DizipubCrawler
from .dizist import DizistCrawler
from .sezonlukdizi import SezonlukDiziCrawler

dizisites = {
    "dizilab": DizilabCrawler,
    "dizipub": DizipubCrawler,
    "sezonlukdizi": SezonlukDiziCrawler,
    "dizimag": DizimagCrawler,
    "dizibox": DiziboxCrawler,
    "diziay": DiziayCrawler,
    "dizist": DizistCrawler,
    "dizimek": DizimekCrawler,
}


class Crawler:
    def __init__(self, site, dizi_url, season_number, episode_number):
        self.site = site
        if self.site in list(dizisites.keys()):
            self.dizicrawler = dizisites[self.site]()
        elif self.site == '':
            self.dizicrawler = None

        self.episode = {"dizi_url": vizontele.slugify(dizi_url),
                        "season": season_number,
                        "episode": episode_number}

    def get_sources(self):
        """
        Runs the crawler and returns the episode with found video and subtitle links
        :return: episode dict
        """
        if self.dizicrawler is not None:
            self.episode = self.dizicrawler.get_sources(self.episode)
        else:
            # Site is not specified, lets check them all
            for site in list(dizisites.keys()):
                self.dizicrawler = dizisites[site]()
                self.episode = self.dizicrawler.get_sources(self.episode)
                if 'video_links' in self.dizicrawler.episode and len(
                        self.dizicrawler.episode['video_links']) > 0:
                    break

        return self.episode



import json
import re

import demjson
import execjs
import requests
from pyquery import PyQuery as pq

from .base import BaseDiziCrawler


class SezonlukDiziCrawler(BaseDiziCrawler):
    def __init__(self):
        BaseDiziCrawler.__init__(self)

    def generate_episode_page_url(self):
        return "http://sezonlukdizi.net/" + self.episode['dizi_url'] + "/" + \
               str(self.episode['season']) + "-sezon-" + str(
            self.episode['episode']) + "-bolum.html"

    def after_body_loaded(self, text):
        page_dom = pq(text)
        player_address = "http:" + page_dom("iframe[height='360']").eq(0).attr("src")

        result = requests.get(player_address, headers=BaseDiziCrawler.headers)

        if result.status_code == 200:
            self.after_sources_loaded(result.text)
            for video_source in self.episode['video_links']:
                if 'http' not in video_source['url']:
                    video_source['url'] = 'http://sezonlukdizi.net' + video_source['url']

            for sub_source in self.episode['subtitle_links']:
                if 'http' not in sub_source['url']:
                    sub_source['url'] = 'http:' + sub_source['url']

        self.episode['site'] = 'sezonlukdizi'

    def after_sources_loaded(self, text):
        video_altyazi_test = re.search(r"(var video(?s).*.\"\}\);)", text).group(1)
        ctx = execjs.compile('function b(){\n' + video_altyazi_test + 'return [video, altyazi];}')
        [sources, subs] = ctx.call("b")

        for source in sources:
            if 'p' not in str(source['label']):
                source['label'] = str(source['label']) + 'p'

            video_link = {"res": source['label'], "url": source['file']}
            self.episode['video_links'].append(video_link)

        for source in subs:
            if source['label'][0] == 'T':
                source['label'] = 'tr'
            elif source['label'][0] == 'E':
                source['label'] = 'en'

            subtitle_link = {"lang": source['label'], "url": source['file'], "kind": "vtt"}
            self.episode['subtitle_links'].append(subtitle_link)



import re

import demjson
import execjs
import requests
from pyquery import PyQuery as pq

from .base import BaseDiziCrawler


class DiziayCrawler(BaseDiziCrawler):
    def __init__(self):
        BaseDiziCrawler.__init__(self)

    def generate_episode_page_url(self):
        return "http://diziay.com/izle/" + self.episode['dizi_url'] + "-" + \
               str(self.episode['season']) + "-sezon-" + str(self.episode['episode']) + "-bolum/"

    def after_body_loaded(self, text):
        page_dom = pq(text)
        player_address = page_dom("iframe[height='375']").attr("src")

        result = requests.get(player_address, headers=BaseDiziCrawler.headers)

        if result.status_code == 200:
            self.after_sources_loaded(result.text)

        self.episode['site'] = 'diziay'

    def after_sources_loaded(self, text):
        eval_text = re.search(r'eval\((.*)\)', text).group(1)
        sources_text = execjs.eval('a=' + eval_text)
        sources_text = re.search(r'source=(.*)\}\]', sources_text).group(1) + '}]'
        sources = demjson.decode(sources_text)

        for source in sources:
            if 'p' not in source['label']:
                source['label'] += 'p'
            video_link = {"res": source['label'], "url": source['file']}
            if "mp4" in source['type']:
                self.episode['video_links'].append(video_link)



from pprint import pprint

from vizontele.crawler import Crawler

episode = Crawler('sezonlukdizi', 'legion', 1, 4).get_sources()
pprint(episode)
assert len(episode['video_links']) > 0
pprint('Sezonlukdizi test successful')

episode = Crawler('dizimek', 'game of thrones', 1, 1).get_sources()
assert len(episode['video_links']) > 0
pprint('Dizimek test successful')

episode = Crawler('dizist', 'family-guy', 1, 1).get_sources()
assert len(episode['video_links']) > 0
pprint('Dizist test successful')

episode = Crawler('dizilab', 'brooklyn-nine-nine', 4, 19).get_sources()
assert len(episode['video_links']) > 0
pprint('Dizilab test successful')

episode = Crawler('dizibox', 'brooklyn-nine-nine', 4, 19).get_sources()
assert len(episode['video_links']) > 0
pprint('Dizibox test successful')

episode = Crawler('dizipub', 'legion', 1, 2).get_sources()
assert len(episode['video_links']) > 0
pprint('Dizipub test successful')

episode = Crawler('dizimag', 'supernatural', 12, 22).get_sources()
assert len(episode['video_links']) > 0
pprint('Dizimag test successful')

episode = Crawler('diziay', 'family guy', 1, 1).get_sources()
assert len(episode['video_links']) > 0
pprint('Diziay test successful')